@@ -1,4 +1,6 @@
 import random
+import time
+
 from thrift.protocol import TBinaryProtocol
 from thrift.transport import TSocket
 from ODtools.hbase_client import *
@@ -26,6 +28,7 @@ class HBaseClient(metaclass=Singleton):
         reconnect hbase
         :return:
         """
+        time.sleep(5)
         if self.servers:
             h_a, h_p = random.choice(self.servers)
             self.client = self.init_client(h_a, h_p)
@@ -121,10 +124,19 @@ class HBaseClient(metaclass=Singleton):
         :param hbase_table: hbase table
         :return:
         """
-        get = TGet()
-        get.row = hbase_row.encode()
-        result = self.client.exists(hbase_table.encode(), get)
-        return result
+        trash = 5
+        for i in range(trash):
+            try:
+                get = TGet()
+                get.row = hbase_row.encode()
+                result = self.client.exists(hbase_table.encode(), get)
+                return result
+            except Exception as e:
+                if i != trash - 1:
+                    self.reconnect()
+                    continue
+                else:
+                    raise e
 
     def ping(self):
         """
